diff --git a/configure.ac b/configure.ac
index 39def82..9b96a32 100644
--- a/configure.ac
+++ b/configure.ac
@@ -174,6 +174,13 @@ if test "x$enable_coverage" = "xyes"; then
         LDFLAGS="${LDFLAGS} --coverage"
 fi
 
+AC_ARG_ENABLE([tests], AC_HELP_STRING([--disable-tests],[Disable internal tests support]),
+		[with_tests=$enableval],[with_tests=yes])
+AM_CONDITIONAL(ENABLE_TESTS, [test "x$with_tests" = "xyes"])
+if test "x$with_tests" = "xyes"; then
+	AC_DEFINE(ENABLE_TESTS, 1, [Enable internal tests support])
+fi
+
 PKG_CHECK_MODULES(DBUS, dbus-1)
 PKG_CHECK_MODULES(XML2, libxml-2.0)
 PKG_CHECK_MODULES(JSONC, json-c, [], [AC_MSG_WARN([Cannot find json-c. Please install libjson-c-devel])])
diff --git a/testsuite-cmp/Makefile.am b/testsuite-cmp/Makefile.am
index 81104bf..9c29477 100644
--- a/testsuite-cmp/Makefile.am
+++ b/testsuite-cmp/Makefile.am
@@ -2,6 +2,7 @@
 # Makefile.am for snapper/testsuite-cmp
 #
 
+if ENABLE_TESTS
 AM_CPPFLAGS = -I$(top_srcdir)
 AM_LDFLAGS = -lboost_system
 
@@ -15,3 +16,4 @@ cmp_SOURCES = cmp.cc
 
 EXTRA_DIST = $(noinst_SCRIPTS)
 
+endif
diff --git a/testsuite-real/Makefile.am b/testsuite-real/Makefile.am
index a3bb2e3..c4e88f4 100644
--- a/testsuite-real/Makefile.am
+++ b/testsuite-real/Makefile.am
@@ -2,6 +2,7 @@
 # Makefile.am for snapper/testsuite-real
 #
 
+if ENABLE_TESTS
 CXXFLAGS += -std=gnu++11
 
 AM_CPPFLAGS = -I$(top_srcdir)
@@ -56,3 +57,4 @@ ascii_file_SOURCES = ascii-file.cc
 
 EXTRA_DIST = $(test_DATA) $(test_SCRIPTS)
 
+endif
diff --git a/testsuite/Makefile.am b/testsuite/Makefile.am
index ccb84d3..409e265 100644
--- a/testsuite/Makefile.am
+++ b/testsuite/Makefile.am
@@ -2,6 +2,7 @@
 # Makefile.am for snapper/testsuite
 #
 
+if ENABLE_TESTS
 AM_CPPFLAGS = -I$(top_srcdir) $(DBUS_CFLAGS)
 
 LDADD = ../snapper/libsnapper.la ../dbus/libdbus.la -lboost_unit_test_framework
@@ -48,3 +49,4 @@ lvm_utils_test_LDADD = -lboost_unit_test_framework ../snapper/libsnapper.la
 range_test_LDADD = -lboost_unit_test_framework ../client/utils/libutils.la
 
 limit_test_LDADD = -lboost_unit_test_framework ../client/utils/libutils.la
+endif
diff --git a/zypp-plugin/testsuite/Makefile.am b/zypp-plugin/testsuite/Makefile.am
index 7b52e13..71cb545 100644
--- a/zypp-plugin/testsuite/Makefile.am
+++ b/zypp-plugin/testsuite/Makefile.am
@@ -1,3 +1,5 @@
+
+if ENABLE_TESTS
 if HAVE_ZYPP
 TEST_LOG_DRIVER = $(SHELL) tap-driver.sh
 
@@ -12,3 +14,4 @@ TESTS = $(check_SCRIPTS)
 
 EXTRA_DIST = $(check_SCRIPTS) $(noinst_SCRIPTS) $(noinst_DATA) tap-driver.sh
 endif
+endif
